import{e as f,ag as _,ak as p,l as s,n as m,g as b,w as c,f as g,K as y,X as v,v as k,p as n,k as w,t as I}from"./jwt-decode.esm-Di13oRQw.js";import{u as T}from"./projectStore-DxrT9Uoq.js";import{A as D,T as S}from"./index-BhmvSrs-.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="eebfb02f-b418-4cbf-8c13-b9cdf6db5d84",e._sentryDebugIdIdentifier="sentry-dbid-eebfb02f-b418-4cbf-8c13-b9cdf6db5d84")}catch{}})();const N=f({__name:"TablesTabs",setup(e){const a=_(),r=p(),d=String(r.name),i=T(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],u=l=>{a.push({name:String(l),params:{projectId:i.projectId}})};return(l,h)=>(b(),m(n(S),{"active-key":n(d),options:o,"onUpdate:activeKey":u},{default:c(()=>[(b(),g(y,null,v(o,t=>k(n(D),{key:t.value,name:t.value},{tab:c(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{N as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-DxOfhk4-.js.map
