import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-CBLuXdnH.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-Di13oRQw.js";import{u as a}from"./projectStore-DxrT9Uoq.js";import"./router-BikqZ_12.js";import"./ts.worker-DMPFqrjQ.js";import"./fetch-D5TanjDu.js";import"./tables-C0s8s7P7.js";import"./string-BzsxlFG6.js";import"./SaveButton-BT8KA6dj.js";import"./ExclamationCircleOutlined-_dIQOe_X.js";import"./CrudView--JrRJYrp.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-zZzp4ncw.js";import"./constants-D5_IKi1U.js";import"./url-BV-AFuGX.js";import"./PhDotsThreeVertical.vue-DOtoPkxt.js";import"./index-CLz4CUqY.js";import"./asyncComputed-DOI-gBUl.js";import"./PhPencil.vue-BmYPt7dI.js";import"./useCodebaseEvents-fWUrfins.js";import"./contracts.generated-DzAwK2c3.js";import"./index-DYCjRMHH.js";import"./project-kyGrP3YJ.js";import"./organizationSwitcher-Cc7ll1IM.js";import"./organization-NLrfpGfD.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="15e73398-f47f-4176-97b6-756aa6049204",o._sentryDebugIdIdentifier="sentry-dbid-15e73398-f47f-4176-97b6-756aa6049204")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),t=new e(r.projectId);return(f,c)=>(s(),n(p,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-vMpAdvJ-.js.map
