import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-BbCWODY7.js";import{e as d,f as i,v as u,p as n,ag as m,ak as l,g as f,aN as _}from"./jwt-decode.esm-Di13oRQw.js";import{u as g}from"./workspaceStore-D9mz6FOR.js";import"./OTPInput-CzNQu672.js";import"./Logo-Dl3wIG-e.js";import"./string-BzsxlFG6.js";import"./CircularLoading-D6n2bEFF.js";import"./index-DYCjRMHH.js";import"./userStore-DtRefrCQ.js";import"./runnerData-PSt4Y1Um.js";import"./url-BV-AFuGX.js";import"./colorHelpers-Bkim6eSt.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="d95aa95f-aac6-429c-984b-cab35ea27ad0",e._sentryDebugIdIdentifier="sentry-dbid-d95aa95f-aac6-429c-984b-cab35ea27ad0")}catch{}})();const b={class:"runner"},y=d({__name:"Login",setup(e){const a=m(),o=l(),r=g(),c=async()=>{const{redirect:t,...s}=o.query;if(t){await a.push({path:t,query:s,params:o.params});return}a.push({name:"playerHome",query:s})};return(t,s)=>(f(),i("div",b,[u(p,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-eG4gfFL0.js.map
