import{e as o,b as s,f as l,g as f,k as i,h as r,I as u,H as a,aN as c}from"./jwt-decode.esm-Di13oRQw.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="895993ab-ff29-4d64-a07f-a00f0bdc14d3",e._sentryDebugIdIdentifier="sentry-dbid-895993ab-ff29-4d64-a07f-a00f0bdc14d3")}catch{}})();const y=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(d,g)=>(f(),l("div",{class:a(["content-layout",{"no-padding":e.noPadding}])},[i("div",{class:a(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:u(t.value)},[r(d.$slots,"default",{},void 0,!0)],6)],2))}}),b=c(y,[["__scopeId","data-v-00e066e8"]]);export{b as C};
//# sourceMappingURL=ContentLayout-CNTDy-m6.js.map
