import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-gbSTYs6a.js";import{B as y}from"./BaseLayout-HZagP0af.js";import{e as l,S as _,a1 as v,aN as u,aJ as b,aK as g,g as m,f as h,k as o,I as s,Q as w,ag as S,n as k,w as n,ak as I,v as i,p as B}from"./jwt-decode.esm-Di13oRQw.js";import{u as $}from"./editor-Bk8PiU7y.js";import{A as L}from"./index-DU3exKux.js";import"./logo-BiWG9_W5.js";import"./Logo-Dl3wIG-e.js";import"./ts.worker-DMPFqrjQ.js";import"./workspaceStore-D9mz6FOR.js";import"./userStore-DtRefrCQ.js";import"./runnerData-PSt4Y1Um.js";import"./url-BV-AFuGX.js";import"./colorHelpers-Bkim6eSt.js";import"./useCodebaseEvents-fWUrfins.js";import"./contracts.generated-DzAwK2c3.js";import"./files-BR_Ygtlm.js";import"./PhBug.vue-XkaUSZT1.js";import"./router-Blo5Kmjn.js";import"./constants-D5_IKi1U.js";import"./index-CLz4CUqY.js";import"./index-vh6DCstS.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="67a54e1e-aa69-4913-a60e-772e51b4676e",e._sentryDebugIdIdentifier="sentry-dbid-67a54e1e-aa69-4913-a60e-772e51b4676e")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(r)}}}),D={class:"v-spinner"};function K(e,r,a,d,p,c){return b((m(),h("div",D,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(x,[["render",K],["__scopeId","data-v-224007fd"]]),R={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=I(),a=S(),d=$();function p(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function c(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=c();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(p),a.push({name:"editor"})}),(t,A)=>(m(),k(y,null,{navbar:n(()=>[i(B(L),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[o("div",R,[i(P)])]),_:1}))}}),re=u(z,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-D5LvIJE7.js.map
