import{P as g}from"./PlayerNavbar-CuuCv8N3.js";import{e as _,ak as i,r as h,b,f as k,n as y,j as w,k as v,p as a,v as L,a4 as C,ag as N,g as c,aN as I}from"./jwt-decode.esm-Di13oRQw.js";import{u as V}from"./workspaceStore-D9mz6FOR.js";import"./userStore-DtRefrCQ.js";import"./metadata-nvVJcWCT.js";import"./PhCursorClick.vue-C3W_0Auv.js";import"./PhHouse.vue-Ya80KDgR.js";import"./PhMagnifyingGlass.vue-Drv7e4a5.js";import"./PhWebhooksLogo.vue-BFXMvocO.js";import"./LoadingOutlined-CwvBrzZA.js";import"./PhSignOut.vue-DE4HE1k8.js";import"./index-vh6DCstS.js";import"./runnerData-PSt4Y1Um.js";import"./url-BV-AFuGX.js";import"./colorHelpers-Bkim6eSt.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="303bc59f-140c-4fc9-a634-be103f15e2e3",o._sentryDebugIdIdentifier="sentry-dbid-303bc59f-140c-4fc9-a634-be103f15e2e3")}catch{}})();const B={class:"main-container"},D={class:"content"},P=_({__name:"Main",setup(o){const e=N(),t=V(),p=i().path,n=h(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},d=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),k("div",B,[a(t).state.workspace?(c(),y(g,{key:0,"current-path":a(p),"hide-login":m.value,"runner-data":a(t).state.workspace,loading:n.value,"show-sidebar":a(t).state.currentPageType==="form",onNavigate:u,onLoginClick:l,onLogoutClick:d},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):w("",!0),v("section",D,[L(f)])])}}}),J=I(P,[["__scopeId","data-v-61bdccea"]]);export{J as default};
//# sourceMappingURL=Main-Dw45fdz3.js.map
