import{N as c}from"./Navbar-CGMqYXco.js";import{e as d,ak as u,b as a,l,a4 as f,f as _,g as b,v as p,k as y,aN as I}from"./jwt-decode.esm-Di13oRQw.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-DRz63FU6.js";import"./constants-D5_IKi1U.js";import"./PhCaretDown.vue-Dt3kvUt8.js";import"./PhPencilSimple.vue-CLExZtLt.js";import"./router-BikqZ_12.js";import"./ts.worker-DMPFqrjQ.js";import"./organization-NLrfpGfD.js";import"./tables-C0s8s7P7.js";import"./string-BzsxlFG6.js";import"./keyboard-BZzzhbw4.js";import"./os-DJRxn5zr.js";import"./projectStore-DxrT9Uoq.js";import"./project-kyGrP3YJ.js";import"./organizationSwitcher-Cc7ll1IM.js";import"./cascaderStore-r9XiP2MY.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-338fsxvf.js";import"./member-CLuuJpEE.js";import"./index-Rn-JPiQc.js";import"./index-BhmvSrs-.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-Cjw0Z8sT.js";import"./PhNotePencil.vue-CLxKojzD.js";import"./PhSignOut.vue-DE4HE1k8.js";import"./index-CLz4CUqY.js";import"./index-vh6DCstS.js";import"./PhPlus.vue-CvJb3QXA.js";import"./omniChatStore-DU1QIfTz.js";import"./files-BR_Ygtlm.js";import"./contracts.generated-DzAwK2c3.js";import"./runnerData-PSt4Y1Um.js";import"./url-BV-AFuGX.js";import"./colorHelpers-Bkim6eSt.js";import"./uuid-BlUX7GeO.js";import"./PhCopySimple.vue-fVReUsij.js";import"./PhSparkle.vue-DuJ5bXLM.js";import"./index-DU3exKux.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="6f61c021-1367-4a0f-b736-e24a749c7bd2",r._sentryDebugIdIdentifier="sentry-dbid-6f61c021-1367-4a0f-b736-e24a749c7bd2")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return b(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[p(e)])])}}}),io=I(w,[["__scopeId","data-v-62f8634d"]]);export{io as default};
//# sourceMappingURL=ConsoleLayout-DDzIJI8n.js.map
